__title__ = 'invain'
__description__ = 'A Python library for getting stock data from Yahoo Finance'
__url__ = 'https://code.inva.in/'
__github_url__ = 'https://github.com/hailfire113/InVaIN'
__version__ = '0.3.1'
__license__ = 'MIT'



import requests
import sys
from .Simple import Simple
from .Utils import *

class Advanced(Simple):
    def __init__(self, ticker, *extras):
        if is_sequence(ticker):
            self.ticker= ticker
        else: self.ticker = [ticker]
        self.add_tickers(extras)
        self.field = []
        del Advanced.change_ticker
        
    #Override method for removal
    def change_ticker(self):
        return ""
        
    #Add Tickers to End of List, Extend Allows for ticker to be a List                
    def add_ticker(self, ticker):
        if is_sequence(ticker):
            self.ticker.extend(ticker)
        else: self.ticker.extend([ticker])
        
                
    #If Someone is Sketch About Singular Form
    def add_tickers(self, tickers, *extras):
        self.add_ticker(tickers)
        self.add_ticker(extras)

    def remove_ticker(self, ticker):
        try:
            if ticker in self.ticker: self.ticker.remove(ticker)
            else: raise ValueError('InVaIN.Advanced() Failed to remove ticker. Ticker not found in list')
        except ValueError as err:
            print(err.args,"\n Non-Fatal Error")
            
#              Add Fields to Custom Field List
#################################################################
    def add_price(self): 
         self.field.extend(['rmp']) 

    def remove_price(self): 
         if 'rmp' in self.field: self.field.remove('rmp') 

    def add_volume(self): 
         self.field.extend(['rmv']) 

    def remove_volume(self): 
         if 'rmv' in self.field: self.field.remove('rmv') 

    def add_ask(self): 
         self.field.extend(['a']) 

    def remove_ask(self): 
         if 'a' in self.field: self.field.remove('a') 

    def add_askSize(self): 
         self.field.extend(['aZ']) 

    def remove_askSize(self): 
         if 'aZ' in self.field: self.field.remove('aZ') 

    def add_averageDailyVolume3Month(self): 
         self.field.extend(['aDy3M']) 

    def remove_averageDailyVolume3Month(self): 
         if 'aDy3M' in self.field: self.field.remove('aDy3M') 

    def add_averageDailyVolume10Day(self): 
         self.field.extend(['aDy10d']) 

    def remove_averageDailyVolume10Day(self): 
         if 'aDy10d' in self.field: self.field.remove('aDy10d') 

    def add_bid(self): 
         self.field.extend(['b']) 

    def remove_bid(self): 
         if 'b' in self.field: self.field.remove('b') 

    def add_bidSize(self): 
         self.field.extend(['bZ']) 

    def remove_bidSize(self): 
         if 'bZ' in self.field: self.field.remove('bZ') 

    def add_bookValue(self): 
         self.field.extend(['bV']) 

    def remove_bookValue(self): 
         if 'bV' in self.field: self.field.remove('bV') 

    def add_currency(self): 
         self.field.extend(['c']) 

    def remove_currency(self): 
         if 'c' in self.field: self.field.remove('c') 

    def add_earningsTimestamp(self): 
         self.field.extend(['eT']) 

    def remove_earningsTimestamp(self): 
         if 'eT' in self.field: self.field.remove('eT') 

    def add_earningsTimestampEnd(self): 
         self.field.extend(['eTE']) 

    def remove_earningsTimestampEnd(self): 
         if 'eTE' in self.field: self.field.remove('eTE') 

    def add_earningsTimestampStart(self): 
         self.field.extend(['eTS']) 

    def remove_earningsTimestampStart(self): 
         if 'eTS' in self.field: self.field.remove('eTS') 

    def add_epsForward(self): 
         self.field.extend(['epsF']) 

    def remove_epsForward(self): 
         if 'epsF' in self.field: self.field.remove('epsF') 

    def add_epsTrailingTwelveMonths(self): 
         self.field.extend(['epsT']) 

    def remove_epsTrailingTwelveMonths(self): 
         if 'epsT' in self.field: self.field.remove('epsT') 

    def add_fiftyDayAverage(self): 
         self.field.extend(['fifDyAvg']) 

    def remove_fiftyDayAverage(self): 
         if 'fifDyAvg' in self.field: self.field.remove('fifDyAvg') 

    def add_fiftyDayAverageChange(self): 
         self.field.extend(['fifDyAvgCh']) 

    def remove_fiftyDayAverageChange(self): 
         if 'fifDyAvgCh' in self.field: self.field.remove('fifDyAvgCh') 

    def add_fiftyDayAverageChangePercent(self): 
         self.field.extend(['fifDyAvgChP']) 

    def remove_fiftyDayAverageChangePercent(self): 
         if 'fifDyAvgChP' in self.field: self.field.remove('fifDyAvgChP') 

    def add_fiftyTwoWeekHigh(self): 
         self.field.extend(['fif2Wh']) 

    def remove_fiftyTwoWeekHigh(self): 
         if 'fif2Wh' in self.field: self.field.remove('fif2Wh') 

    def add_fiftyTwoWeekHighChange(self): 
         self.field.extend(['fif2WhCh']) 

    def remove_fiftyTwoWeekHighChange(self): 
         if 'fif2WhCh' in self.field: self.field.remove('fif2WhCh') 

    def add_fiftyTwoWeekHighChangePercent(self): 
         self.field.extend(['fif2WhChP']) 

    def remove_fiftyTwoWeekHighChangePercent(self): 
         if 'fif2WhChP' in self.field: self.field.remove('fif2WhChP') 

    def add_fiftyTwoWeekLow(self): 
         self.field.extend(['fif2Wl']) 

    def remove_fiftyTwoWeekLow(self): 
         if 'fif2Wl' in self.field: self.field.remove('fif2Wl') 

    def add_fiftyTwoWeekLowChange(self): 
         self.field.extend(['fif2WlCh']) 

    def remove_fiftyTwoWeekLowChange(self): 
         if 'fif2WlCh' in self.field: self.field.remove('fif2WlCh') 

    def add_fiftyTwoWeekLowChangePercent(self): 
         self.field.extend(['fif2WlChP']) 

    def remove_fiftyTwoWeekLowChangePercent(self): 
         if 'fif2WlChP' in self.field: self.field.remove('fif2WlChP') 

    def add_financialCurrency(self): 
         self.field.extend(['fC']) 

    def remove_financialCurrency(self): 
         if 'fC' in self.field: self.field.remove('fC') 

    def add_forwardPE(self): 
         self.field.extend(['fPE']) 

    def remove_forwardPE(self): 
         if 'fPE' in self.field: self.field.remove('fPE') 

    def add_fullExchangeName(self): 
         self.field.extend(['fEXN']) 

    def remove_fullExchangeName(self): 
         if 'fEXN' in self.field: self.field.remove('fEXN') 

    def add_gmtOffSetMilliseconds(self): 
         self.field.extend(['gmtOff']) 

    def remove_gmtOffSetMilliseconds(self): 
         if 'gmtOff' in self.field: self.field.remove('gmtOff') 

    def add_longName(self): 
         self.field.extend(['lN']) 

    def remove_longName(self): 
         if 'lN' in self.field: self.field.remove('lN') 

    def add_marketCap(self): 
         self.field.extend(['mC']) 

    def remove_marketCap(self): 
         if 'mC' in self.field: self.field.remove('mC') 

    def add_marketChange(self): 
         self.field.extend(['regMCh']) 

    def remove_marketChange(self): 
         if 'regMCh' in self.field: self.field.remove('regMCh') 

    def add_marketChangePercent(self): 
         self.field.extend(['regMChP']) 

    def remove_marketChangePercent(self): 
         if 'regMChP' in self.field: self.field.remove('regMChP') 

    def add_marketDayHigh(self): 
         self.field.extend(['regMDyH']) 

    def remove_marketDayHigh(self): 
         if 'regMDyH' in self.field: self.field.remove('regMDyH') 

    def add_marketDayLow(self): 
         self.field.extend(['regMDyL']) 

    def remove_marketDayLow(self): 
         if 'regMDyL' in self.field: self.field.remove('regMDyL') 

    def add_marketOpen(self): 
         self.field.extend(['regMO']) 

    def remove_marketOpen(self): 
         if 'regMO' in self.field: self.field.remove('regMO') 

    def add_marketPreviousClose(self): 
         self.field.extend(['regMPvC']) 

    def remove_marketPreviousClose(self): 
         if 'regMPvC' in self.field: self.field.remove('regMPvC') 

    def add_marketTime(self): 
         self.field.extend(['rmt']) 

    def remove_marketTime(self): 
         if 'rmt' in self.field: self.field.remove('rmt') 

    def add_postMarketChange(self): 
         self.field.extend(['pmCh']) 

    def remove_postMarketChange(self): 
         if 'pmCh' in self.field: self.field.remove('pmCh') 

    def add_postMarketChangePercent(self): 
         self.field.extend(['pmChP']) 

    def remove_postMarketChangePercent(self): 
         if 'pmChP' in self.field: self.field.remove('pmChP') 

    def add_postMarketPrice(self): 
         self.field.extend(['pmP']) 

    def remove_postMarketPrice(self): 
         if 'pmP' in self.field: self.field.remove('pmP') 

    def add_postMarketTime(self): 
         self.field.extend(['pmT']) 

    def remove_postMarketTime(self): 
         if 'pmT' in self.field: self.field.remove('pmT') 

    def add_priceHint(self): 
         self.field.extend(['pH']) 

    def remove_priceHint(self): 
         if 'pH' in self.field: self.field.remove('pH') 

    def add_priceToBook(self): 
         self.field.extend(['p2B']) 

    def remove_priceToBook(self): 
         if 'p2B' in self.field: self.field.remove('p2B') 

    def add_sharesOutstanding(self): 
         self.field.extend(['sho']) 

    def remove_sharesOutstanding(self): 
         if 'sho' in self.field: self.field.remove('sho') 

    def add_shortName(self): 
         self.field.extend(['shN']) 

    def remove_shortName(self): 
         if 'shN' in self.field: self.field.remove('shN') 

    def add_symbol(self): 
         self.field.extend(['sym']) 

    def remove_symbol(self): 
         if 'sym' in self.field: self.field.remove('sym') 

    def add_tradeable(self): 
         self.field.extend(['tdbl']) 

    def remove_tradeable(self): 
         if 'tdbl' in self.field: self.field.remove('tdbl') 

    def add_trailingPE(self): 
         self.field.extend(['tPE']) 

    def remove_trailingPE(self): 
         if 'tPE' in self.field: self.field.remove('tPE') 

    def add_twoHundredDayAverage(self): 
         self.field.extend(['tHdDyAv']) 

    def remove_twoHundredDayAverage(self): 
         if 'tHdDyAv' in self.field: self.field.remove('tHdDyAv') 

    def add_twoHundredDayAverageChange(self): 
         self.field.extend(['tHdDyAvCh']) 

    def remove_twoHundredDayAverageChange(self): 
         if 'tHdDyAvCh' in self.field: self.field.remove('tHdDyAvCh') 

    def add_twoHundredDayAverageChangePercent(self): 
         self.field.extend(['tHdDyAvChP']) 

    def remove_twoHundredDayAverageChangePercent(self): 
         if 'tHdDyAvChP' in self.field: self.field.remove('tHdDyAvChP') 


#           Custom Data 
##############################################################
    def get_customData(self):
        try:
            if self.field :
                data = fetch(self.ticker,self.field)
            else: raise ValueError('InVaIN.Advanced() Missing fields for customData.')
        
        except ValueError as err:
            print(err.args,"\n Abortting Script")
            sys.exit(1)
        return data



from .Utils import *
import sys

class Simple():

    def __init__(self, symbol):
        try:
            if is_sequence(symbol) or not isinstance(symbol, str):
                raise ValueError('InVaIN.Simple() expects a string as the only parameter')
            else: self.ticker = symbol
        except ValueError as err:
            print(err.args,"\nQuitting")
            sys.exit(1) 

    def change_ticker(self, symbol):
        try:
            if is_sequence(symbol) or not isinstance(symbol, str):
                raise ValueError('InVaIN.Simple() expects a string as the only parameter')
            else: self.ticker = symbol
        except ValueError as err:
            print(err.args,"\nQuitting")
            sys.exit(1)
    
    def get_price(self): 
         #Pull Data 
         data = fetch(self.ticker,'rmp') 

         #Isolate Stock Data
         if len(data) > 1:
             for ticker in data:
                 data[ticker] = data[ticker]['price']
         else: data = list(data.values())[0]['price']
         return data

    def get_volume(self): 
         #Pull Data 
         data = fetch(self.ticker,'rmv') 

         #Isolate Stock Data
         if len(data) > 1:
             for ticker in data:
                 data[ticker] = data[ticker]['volume']
         else: data = list(data.values())[0]['volume']
         return data

    def get_ask(self): 
         #Pull Data 
         data = fetch(self.ticker,'a') 

         #Isolate Stock Data
         if len(data) > 1:
             for ticker in data:
                 data[ticker] = data[ticker]['ask']
         else: data = list(data.values())[0]['ask']
         return data

    def get_askSize(self): 
         #Pull Data 
         data = fetch(self.ticker,'aZ') 

         #Isolate Stock Data
         if len(data) > 1:
             for ticker in data:
                 data[ticker] = data[ticker]['askSize']
         else: data = list(data.values())[0]['askSize']
         return data

    def get_averageDailyVolume3Month(self): 
         #Pull Data 
         data = fetch(self.ticker,'aDy3M') 

         #Isolate Stock Data
         if len(data) > 1:
             for ticker in data:
                 data[ticker] = data[ticker]['averageDailyVolume3Month']
         else: data = list(data.values())[0]['averageDailyVolume3Month']
         return data

    def get_averageDailyVolume10Day(self): 
         #Pull Data 
         data = fetch(self.ticker,'aDy10d') 

         #Isolate Stock Data
         if len(data) > 1:
             for ticker in data:
                 data[ticker] = data[ticker]['averageDailyVolume10Day']
         else: data = list(data.values())[0]['averageDailyVolume10Day']
         return data

    def get_bid(self): 
         #Pull Data 
         data = fetch(self.ticker,'b') 

         #Isolate Stock Data
         if len(data) > 1:
             for ticker in data:
                 data[ticker] = data[ticker]['bid']
         else: data = list(data.values())[0]['bid']
         return data

    def get_bidSize(self): 
         #Pull Data 
         data = fetch(self.ticker,'bZ') 

         #Isolate Stock Data
         if len(data) > 1:
             for ticker in data:
                 data[ticker] = data[ticker]['bidSize']
         else: data = list(data.values())[0]['bidSize']
         return data

    def get_bookValue(self): 
         #Pull Data 
         data = fetch(self.ticker,'bV') 

         #Isolate Stock Data
         if len(data) > 1:
             for ticker in data:
                 data[ticker] = data[ticker]['bookValue']
         else: data = list(data.values())[0]['bookValue']
         return data

    def get_currency(self): 
         #Pull Data 
         data = fetch(self.ticker,'c') 

         #Isolate Stock Data
         if len(data) > 1:
             for ticker in data:
                 data[ticker] = data[ticker]['currency']
         else: data = list(data.values())[0]['currency']
         return data

    def get_earningsTimestamp(self): 
         #Pull Data 
         data = fetch(self.ticker,'eT') 

         #Isolate Stock Data
         if len(data) > 1:
             for ticker in data:
                 data[ticker] = data[ticker]['earningsTimestamp']
         else: data = list(data.values())[0]['earningsTimestamp']
         return data

    def get_earningsTimestampEnd(self): 
         #Pull Data 
         data = fetch(self.ticker,'eTE') 

         #Isolate Stock Data
         if len(data) > 1:
             for ticker in data:
                 data[ticker] = data[ticker]['earningsTimestampEnd']
         else: data = list(data.values())[0]['earningsTimestampEnd']
         return data

    def get_earningsTimestampStart(self): 
         #Pull Data 
         data = fetch(self.ticker,'eTS') 

         #Isolate Stock Data
         if len(data) > 1:
             for ticker in data:
                 data[ticker] = data[ticker]['earningsTimestampStart']
         else: data = list(data.values())[0]['earningsTimestampStart']
         return data

    def get_epsForward(self): 
         #Pull Data 
         data = fetch(self.ticker,'epsF') 

         #Isolate Stock Data
         if len(data) > 1:
             for ticker in data:
                 data[ticker] = data[ticker]['epsForward']
         else: data = list(data.values())[0]['epsForward']
         return data

    def get_epsTrailingTwelveMonths(self): 
         #Pull Data 
         data = fetch(self.ticker,'epsT') 

         #Isolate Stock Data
         if len(data) > 1:
             for ticker in data:
                 data[ticker] = data[ticker]['epsTrailingTwelveMonths']
         else: data = list(data.values())[0]['epsTrailingTwelveMonths']
         return data

    def get_fiftyDayAverage(self): 
         #Pull Data 
         data = fetch(self.ticker,'fifDyAvg') 

         #Isolate Stock Data
         if len(data) > 1:
             for ticker in data:
                 data[ticker] = data[ticker]['fiftyDayAverage']
         else: data = list(data.values())[0]['fiftyDayAverage']
         return data

    def get_fiftyDayAverageChange(self): 
         #Pull Data 
         data = fetch(self.ticker,'fifDyAvgCh') 

         #Isolate Stock Data
         if len(data) > 1:
             for ticker in data:
                 data[ticker] = data[ticker]['fiftyDayAverageChange']
         else: data = list(data.values())[0]['fiftyDayAverageChange']
         return data

    def get_fiftyDayAverageChangePercent(self): 
         #Pull Data 
         data = fetch(self.ticker,'fifDyAvgChP') 

         #Isolate Stock Data
         if len(data) > 1:
             for ticker in data:
                 data[ticker] = data[ticker]['fiftyDayAverageChangePercent']
         else: data = list(data.values())[0]['fiftyDayAverageChangePercent']
         return data

    def get_fiftyTwoWeekHigh(self): 
         #Pull Data 
         data = fetch(self.ticker,'fif2Wh') 

         #Isolate Stock Data
         if len(data) > 1:
             for ticker in data:
                 data[ticker] = data[ticker]['fiftyTwoWeekHigh']
         else: data = list(data.values())[0]['fiftyTwoWeekHigh']
         return data

    def get_fiftyTwoWeekHighChange(self): 
         #Pull Data 
         data = fetch(self.ticker,'fif2WhCh') 

         #Isolate Stock Data
         if len(data) > 1:
             for ticker in data:
                 data[ticker] = data[ticker]['fiftyTwoWeekHighChange']
         else: data = list(data.values())[0]['fiftyTwoWeekHighChange']
         return data

    def get_fiftyTwoWeekHighChangePercent(self): 
         #Pull Data 
         data = fetch(self.ticker,'fif2WhChP') 

         #Isolate Stock Data
         if len(data) > 1:
             for ticker in data:
                 data[ticker] = data[ticker]['fiftyTwoWeekHighChangePercent']
         else: data = list(data.values())[0]['fiftyTwoWeekHighChangePercent']
         return data

    def get_fiftyTwoWeekLow(self): 
         #Pull Data 
         data = fetch(self.ticker,'fif2Wl') 

         #Isolate Stock Data
         if len(data) > 1:
             for ticker in data:
                 data[ticker] = data[ticker]['fiftyTwoWeekLow']
         else: data = list(data.values())[0]['fiftyTwoWeekLow']
         return data

    def get_fiftyTwoWeekLowChange(self): 
         #Pull Data 
         data = fetch(self.ticker,'fif2WlCh') 

         #Isolate Stock Data
         if len(data) > 1:
             for ticker in data:
                 data[ticker] = data[ticker]['fiftyTwoWeekLowChange']
         else: data = list(data.values())[0]['fiftyTwoWeekLowChange']
         return data

    def get_fiftyTwoWeekLowChangePercent(self): 
         #Pull Data 
         data = fetch(self.ticker,'fif2WlChP') 

         #Isolate Stock Data
         if len(data) > 1:
             for ticker in data:
                 data[ticker] = data[ticker]['fiftyTwoWeekLowChangePercent']
         else: data = list(data.values())[0]['fiftyTwoWeekLowChangePercent']
         return data

    def get_financialCurrency(self): 
         #Pull Data 
         data = fetch(self.ticker,'fC') 

         #Isolate Stock Data
         if len(data) > 1:
             for ticker in data:
                 data[ticker] = data[ticker]['financialCurrency']
         else: data = list(data.values())[0]['financialCurrency']
         return data

    def get_forwardPE(self): 
         #Pull Data 
         data = fetch(self.ticker,'fPE') 

         #Isolate Stock Data
         if len(data) > 1:
             for ticker in data:
                 data[ticker] = data[ticker]['forwardPE']
         else: data = list(data.values())[0]['forwardPE']
         return data

    def get_fullExchangeName(self): 
         #Pull Data 
         data = fetch(self.ticker,'fEXN') 

         #Isolate Stock Data
         if len(data) > 1:
             for ticker in data:
                 data[ticker] = data[ticker]['fullExchangeName']
         else: data = list(data.values())[0]['fullExchangeName']
         return data

    def get_gmtOffSetMilliseconds(self): 
         #Pull Data 
         data = fetch(self.ticker,'gmtOff') 

         #Isolate Stock Data
         if len(data) > 1:
             for ticker in data:
                 data[ticker] = data[ticker]['gmtOffSetMilliseconds']
         else: data = list(data.values())[0]['gmtOffSetMilliseconds']
         return data

    def get_longName(self): 
         #Pull Data 
         data = fetch(self.ticker,'lN') 

         #Isolate Stock Data
         if len(data) > 1:
             for ticker in data:
                 data[ticker] = data[ticker]['longName']
         else: data = list(data.values())[0]['longName']
         return data

    def get_marketCap(self): 
         #Pull Data 
         data = fetch(self.ticker,'mC') 

         #Isolate Stock Data
         if len(data) > 1:
             for ticker in data:
                 data[ticker] = data[ticker]['marketCap']
         else: data = list(data.values())[0]['marketCap']
         return data

    def get_marketChange(self): 
         #Pull Data 
         data = fetch(self.ticker,'regMCh') 

         #Isolate Stock Data
         if len(data) > 1:
             for ticker in data:
                 data[ticker] = data[ticker]['marketChange']
         else: data = list(data.values())[0]['marketChange']
         return data

    def get_marketChangePercent(self): 
         #Pull Data 
         data = fetch(self.ticker,'regMChP') 

         #Isolate Stock Data
         if len(data) > 1:
             for ticker in data:
                 data[ticker] = data[ticker]['marketChangePercent']
         else: data = list(data.values())[0]['marketChangePercent']
         return data

    def get_marketDayHigh(self): 
         #Pull Data 
         data = fetch(self.ticker,'regMDyH') 

         #Isolate Stock Data
         if len(data) > 1:
             for ticker in data:
                 data[ticker] = data[ticker]['marketDayHigh']
         else: data = list(data.values())[0]['marketDayHigh']
         return data

    def get_marketDayLow(self): 
         #Pull Data 
         data = fetch(self.ticker,'regMDyL') 

         #Isolate Stock Data
         if len(data) > 1:
             for ticker in data:
                 data[ticker] = data[ticker]['marketDayLow']
         else: data = list(data.values())[0]['marketDayLow']
         return data

    def get_marketOpen(self): 
         #Pull Data 
         data = fetch(self.ticker,'regMO') 

         #Isolate Stock Data
         if len(data) > 1:
             for ticker in data:
                 data[ticker] = data[ticker]['marketOpen']
         else: data = list(data.values())[0]['marketOpen']
         return data

    def get_marketPreviousClose(self): 
         #Pull Data 
         data = fetch(self.ticker,'regMPvC') 

         #Isolate Stock Data
         if len(data) > 1:
             for ticker in data:
                 data[ticker] = data[ticker]['marketPreviousClose']
         else: data = list(data.values())[0]['marketPreviousClose']
         return data

    def get_marketTime(self): 
         #Pull Data 
         data = fetch(self.ticker,'rmt') 

         #Isolate Stock Data
         if len(data) > 1:
             for ticker in data:
                 data[ticker] = data[ticker]['marketTime']
         else: data = list(data.values())[0]['marketTime']
         return data

    def get_postMarketChange(self): 
         #Pull Data 
         data = fetch(self.ticker,'pmCh') 

         #Isolate Stock Data
         if len(data) > 1:
             for ticker in data:
                 data[ticker] = data[ticker]['postMarketChange']
         else: data = list(data.values())[0]['postMarketChange']
         return data

    def get_postMarketChangePercent(self): 
         #Pull Data 
         data = fetch(self.ticker,'pmChP') 

         #Isolate Stock Data
         if len(data) > 1:
             for ticker in data:
                 data[ticker] = data[ticker]['postMarketChangePercent']
         else: data = list(data.values())[0]['postMarketChangePercent']
         return data

    def get_postMarketPrice(self): 
         #Pull Data 
         data = fetch(self.ticker,'pmP') 

         #Isolate Stock Data
         if len(data) > 1:
             for ticker in data:
                 data[ticker] = data[ticker]['postMarketPrice']
         else: data = list(data.values())[0]['postMarketPrice']
         return data

    def get_postMarketTime(self): 
         #Pull Data 
         data = fetch(self.ticker,'pmT') 

         #Isolate Stock Data
         if len(data) > 1:
             for ticker in data:
                 data[ticker] = data[ticker]['postMarketTime']
         else: data = list(data.values())[0]['postMarketTime']
         return data

    def get_priceHint(self): 
         #Pull Data 
         data = fetch(self.ticker,'pH') 

         #Isolate Stock Data
         if len(data) > 1:
             for ticker in data:
                 data[ticker] = data[ticker]['priceHint']
         else: data = list(data.values())[0]['priceHint']
         return data

    def get_priceToBook(self): 
         #Pull Data 
         data = fetch(self.ticker,'p2B') 

         #Isolate Stock Data
         if len(data) > 1:
             for ticker in data:
                 data[ticker] = data[ticker]['priceToBook']
         else: data = list(data.values())[0]['priceToBook']
         return data

    def get_sharesOutstanding(self): 
         #Pull Data 
         data = fetch(self.ticker,'sho') 

         #Isolate Stock Data
         if len(data) > 1:
             for ticker in data:
                 data[ticker] = data[ticker]['sharesOutstanding']
         else: data = list(data.values())[0]['sharesOutstanding']
         return data

    def get_shortName(self): 
         #Pull Data 
         data = fetch(self.ticker,'shN') 

         #Isolate Stock Data
         if len(data) > 1:
             for ticker in data:
                 data[ticker] = data[ticker]['shortName']
         else: data = list(data.values())[0]['shortName']
         return data

    def get_symbol(self): 
         return self.ticker

    def get_tradeable(self): 
         #Pull Data 
         data = fetch(self.ticker,'tdbl') 

         #Isolate Stock Data
         if len(data) > 1:
             for ticker in data:
                 data[ticker] = data[ticker]['tradeable']
         else: data = list(data.values())[0]['tradeable']
         return data

    def get_trailingPE(self): 
         #Pull Data 
         data = fetch(self.ticker,'tPE') 

         #Isolate Stock Data
         if len(data) > 1:
             for ticker in data:
                 data[ticker] = data[ticker]['trailingPE']
         else: data = list(data.values())[0]['trailingPE']
         return data

    def get_twoHundredDayAverage(self): 
         #Pull Data 
         data = fetch(self.ticker,'tHdDyAv') 

         #Isolate Stock Data
         if len(data) > 1:
             for ticker in data:
                 data[ticker] = data[ticker]['twoHundredDayAverage']
         else: data = list(data.values())[0]['twoHundredDayAverage']
         return data

    def get_twoHundredDayAverageChange(self): 
         #Pull Data 
         data = fetch(self.ticker,'tHdDyAvCh') 

         #Isolate Stock Data
         if len(data) > 1:
             for ticker in data:
                 data[ticker] = data[ticker]['twoHundredDayAverageChange']
         else: data = list(data.values())[0]['twoHundredDayAverageChange']
         return data

    def get_twoHundredDayAverageChangePercent(self): 
         #Pull Data 
         data = fetch(self.ticker,'tHdDyAvChP') 

         #Isolate Stock Data
         if len(data) > 1:
             for ticker in data:
                 data[ticker] = data[ticker]['twoHundredDayAverageChangePercent']
         else: data = list(data.values())[0]['twoHundredDayAverageChangePercent']
         return data





    




import requests
from .__version__ import __version__

def is_sequence(arg):
    #If arg has strip function it is a String so not sequence. If it has __getitem__ or __iter__ attribute it is iterable
    return not hasattr(arg, "strip") and (hasattr(arg, "__getitem__") or hasattr(arg, "__iter__"))

def fetch(tickers, fields):
        BASE_URL = 'http://aws.inva.in/quotes'
        headers = {'User-Agent': 'InVaIN/'+__version__}        

        #Stringify if list
        if is_sequence(tickers):
            tickers = ','.join(tickers)
            
        if is_sequence(fields):
            fields = ','.join(fields)
            
        #Prepare the Parameters
        temp = {'t':tickers, 'f': fields}        

        #Pull Stock Data
        response = requests.get(BASE_URL, params = temp, headers=headers)

        #Parse into Dict Object
        data = response.json()

        #return data
        return data



from setuptools import setup, find_packages
# To use a consistent encoding
from codecs import open
from os import path

here = path.abspath(path.dirname(__file__))

about = {}
with open(path.join(here, 'invain', '__version__.py'),
          'r', 'utf-8') as f:
    exec(f.read(), about)

with open(path.join(here, 'README.rst'), encoding='utf-8') as f:
    long_description = f.read()

packages=find_packages(exclude=['contrib', 'docs', 'tests*'])

setup(
  name=about['__title__'],
  version=about['__version__'],
  description=about['__description__'],
  long_description = long_description,
  author = 'Alan Arechiga',
  author_email = 'alan@macler.us',
  license=about['__license__'],
  url=about['__github_url__'],
  download_url = 'https://github.com/hailfire113/InVaIN/archive/0.1.tar.gz',
  keywords = ['invain', 'stocks', 'data','finance', 'yahoo','quotes'],
  classifiers=[
    'Development Status :: 3 - Alpha',
    'Intended Audience :: Developers',
    'Intended Audience :: Financial and Insurance Industry',
    'Topic :: Software Development :: Libraries :: Python Modules',
    'Topic :: Office/Business :: Financial',
    'License :: OSI Approved :: MIT License',
    'Programming Language :: Python :: 3',
    'Programming Language :: Python :: 3.3',
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
   ],
   packages=find_packages(exclude=['contrib', 'docs', 'tests']),
   install_requires=['requests'],
)
